# perkeepy

Python utilities for Perkeep.

I have recently started hacking on [Perkeep](https://perkeep.org/) and implementing some of the internals in Python helps me validate my understanding of the codebase. The intended purpose is at least to be able to browse a Perkeep repository without the Go implementation.
